# WriteOffInvoiceRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**integration_id__ns** | **str** | ID of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**integration_status__ns** | **str** | Status of the credit memo&#39;s synchronization with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**origin__ns** | **str** | Origin of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**sync_date__ns** | **str** | Date when the credit memo was synchronized with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**transaction__ns** | **str** | Related transaction in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**comment** | **str** | Comments about the write-off. The comment is used as the comment of the credit memo generated by writing off the specified invoice.  | [optional] 
**amount** | **float** |  | [optional] 
**tax_auto_calculation** | **bool** | Whether to automatically calculate taxes in the credit memo. | [optional] 
**revenue_impacting** | **str** |  | [optional] [default to 'Yes']
**non_revenue_write_off_accounting_code** | **str** |  | [optional] 
**items** | [**List[CreditMemoItemFromWriteOffInvoice]**](CreditMemoItemFromWriteOffInvoice.md) | Container for items. This field is optional.  **Note:** If specified, you must specify ALL the items of the invoice. The entire balance of the invoice will be written off, you cannot just write off some items of the invoice.  | [optional] 
**memo_date** | **date** | The date when the credit memo was created, in &#x60;yyyy-mm-dd&#x60; format. The memo date must be later than or equal to the invoice date.  The default value is the date when you write off the invoice.  | [optional] 
**reason_code** | **str** | A code identifying the reason for the transaction. The value must be an existing reason code or empty. If you do not specify a value, Zuora uses the default reason code &#x60;Write-off&#x60;.  | [optional] 

## Example

```python
from zuora_sdk.models.write_off_invoice_request import WriteOffInvoiceRequest

# TODO update the JSON string below
json = "{}"
# create an instance of WriteOffInvoiceRequest from a JSON string
write_off_invoice_request_instance = WriteOffInvoiceRequest.from_json(json)
# print the JSON string representation of the object
print(WriteOffInvoiceRequest.to_json())

# convert the object into a dict
write_off_invoice_request_dict = write_off_invoice_request_instance.to_dict()
# create an instance of WriteOffInvoiceRequest from a dict
write_off_invoice_request_from_dict = WriteOffInvoiceRequest.from_dict(write_off_invoice_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


